@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2022 Canonical, Ltd.
+ * Copyright (C) 2022-2024 Canonical, Ltd.
  * Author: Danilo Egea Gondolfo <danilo.egea.gondolfo@canonical.com>
+ * Author: Lukas Märdian <slyon@ubuntu.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,18 +16,23 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/*! \file types.h
- *  \brief Definition of public types and placeholders.
+/**
+ * @file  types.h
+ * @brief Definition of public Netplan types.
  */
 
 #pragma once
 
+/// Symbols that are considered part of Netplan public API.
 #define NETPLAN_PUBLIC __attribute__ ((visibility("default")))
+/// Symbols that are used internally by Netplan.
+/// @warning Do not use those symbols in an external codebase, they might be dropped or changed without notice.
 #define NETPLAN_INTERNAL __attribute__ ((visibility("default")))
-#define NETPLAN_ABI __attribute__ ((visibility("default")))
-
+/// Symbols that are outdated and should not be used anymore.
+/// @note Those symbols will be dropped in the future.
 #define NETPLAN_DEPRECATED __attribute__ ((deprecated))
 
+/// Error of value `-2` to indicate an issue with the buffer.
 #define NETPLAN_BUFFER_TOO_SMALL -2
 
 
@@ -36,6 +42,7 @@
 
 #include <glib.h>
 
+/// Network interface types supported by Netplan.
 typedef enum {
     NETPLAN_DEF_TYPE_NONE,
     /* physical devices */
@@ -63,14 +70,19 @@ typedef enum {
     NETPLAN_DEF_TYPE_MAX_
 } NetplanDefType;
 
+/// Private data structure to contain parsed but unvalidated Netplan configuration.
+/// See @ref netplan_parser_new and related accessor functions.
 typedef struct netplan_parser NetplanParser;
 
-/**
- * Represent a configuration stanza
- */
-typedef struct netplan_net_definition NetplanNetDefinition;
+/// Private data structure to contain validated Netplan configuration, ready for writing to disk.
+/// See @ref netplan_state_new and related accessor functions.
 typedef struct netplan_state NetplanState;
 
+/// Private data structure to contain individual settings per Netplan ID.
+/// See @ref netplan_state_get_netdef, @ref netplan_netdef_get_id and related accessor functions.
+typedef struct netplan_net_definition NetplanNetDefinition;
+
+/// Renderer backends supported by Netplan.
 typedef enum {
     NETPLAN_BACKEND_NONE,
     NETPLAN_BACKEND_NETWORKD,
@@ -79,10 +91,19 @@ typedef enum {
     NETPLAN_BACKEND_MAX_,
 } NetplanBackend;
 
+/// Private data structure for error reporting.
+/// See @ref netplan_error_code, @ref netplan_error_message and @ref netplan_error_clear.
 typedef GError NetplanError;
 
+/// Private data structure to iterate through a list of @ref NetplanNetDefinition inside @ref NetplanState.
+/// See @ref netplan_state_iterator_init and related accessor functions.
 typedef struct _NetplanStateIterator NetplanStateIterator;
 
+/**
+ * @brief   Defining a non-opaque placeholder type for the private `struct netplan_state_iterator`.
+ * @details Do not use directly. Use @ref NetplanStateIterator instead. Enables consumers to place the iterator at the stack.
+ * @note    The idea is based on the GLib implementation of iterators.
+ */
 struct _NetplanStateIterator {
     void* placeholder;
 };
@@ -94,56 +115,51 @@ struct _NetplanStateIterator {
  * python-cffi/netplan/_utils.py must be updated with the new entries.
  */
 
+/// Defining different classes of @ref NetplanError.
 enum NETPLAN_ERROR_DOMAINS {
-    NETPLAN_PARSER_ERROR = 1,
-    NETPLAN_VALIDATION_ERROR,
-    NETPLAN_FILE_ERROR,
-    NETPLAN_BACKEND_ERROR,
-    NETPLAN_EMITTER_ERROR,
-    NETPLAN_FORMAT_ERROR,
+    NETPLAN_PARSER_ERROR = 1, ///< See @ref NETPLAN_PARSER_ERRORS
+    NETPLAN_VALIDATION_ERROR, ///< See @ref NETPLAN_VALIDATION_ERRORS
+    NETPLAN_FILE_ERROR, ///< Returns `errno` as the @ref NetplanError code and a corresponding message.
+    NETPLAN_BACKEND_ERROR, ///< See @ref NETPLAN_BACKEND_ERRORS
+    NETPLAN_EMITTER_ERROR, ///< See @ref NETPLAN_EMITTER_ERRORS
+    NETPLAN_FORMAT_ERROR, ///< See @ref NETPLAN_FORMAT_ERRORS
 };
 
-/*
- * Errors for domain NETPLAN_PARSER_ERROR
- *
- * PARSER_ERRORS are expected to contain the file name, line and column numbers
+/**
+ * @brief   Errors for domain @ref NETPLAN_PARSER_ERROR.
+ * @details Such errors are expected to contain the file name,
+ *          line and column numbers.
  */
 enum NETPLAN_PARSER_ERRORS {
     NETPLAN_ERROR_INVALID_YAML,
     NETPLAN_ERROR_INVALID_CONFIG
 };
 
-/*
- * Errors for domain NETPLAN_VALIDATION_ERROR
- *
- * VALIDATION_ERRORS are expected to contain only the YAML file name
- * where the error was found.
+/**
+ * @brief   Errors for domain @ref NETPLAN_VALIDATION_ERROR.
+ * @details Such errors are expected to contain only the YAML file name
+ *          where the error was found.
  */
 enum NETPLAN_VALIDATION_ERRORS {
     NETPLAN_ERROR_CONFIG_GENERIC,
     NETPLAN_ERROR_CONFIG_VALIDATION,
 };
 
-/*
- * Errors for domain NETPLAN_BACKEND_ERROR
- */
+/// @brief Errors for domain @ref NETPLAN_BACKEND_ERROR.
 enum NETPLAN_BACKEND_ERRORS {
     NETPLAN_ERROR_UNSUPPORTED,
     NETPLAN_ERROR_VALIDATION,
 };
 
-/*
- * Errors for domain NETPLAN_EMITTER_ERROR
- */
+/// @brief Errors for domain @ref NETPLAN_EMITTER_ERROR.
 enum NETPLAN_EMITTER_ERRORS {
     NETPLAN_ERROR_YAML_EMITTER,
 };
 
-/*
- * Errors for domain NETPLAN_FORMAT_ERROR
- *
- * FORMAT_ERRORS are generic errors emitted from contexts where information
- * like the file name is not known.
+/**
+ * @brief   Errors for domain @ref NETPLAN_FORMAT_ERROR.
+ * @details Such errors are generic errors emitted from contexts where information
+ *          such as the file name is not known.
  */
 enum NETPLAN_FORMAT_ERRORS {
     NETPLAN_ERROR_FORMAT_INVALID_YAML,
