@@ -31,6 +31,11 @@ from netplan import NetDefinition, NetplanException
 NM_SERVICE_NAME = 'NetworkManager.service'
 NM_SNAP_SERVICE_NAME = 'snap.network-manager.networkmanager.service'
 
+OLD_RT_TABLES_PATH = '/etc/iproute2/rt_tables'
+NEW_RT_TABLES_PATH = '/usr/share/iproute2/rt_tables'
+RT_TABLES_DEFAULT = {0: 'unspec', 253: 'default', 254: 'main', 255: 'local',
+                     'unspec': 0, 'default': 253, 'main': 254, 'local': 255}
+
 config_errors = (ConfigurationError, NetplanException, RuntimeError)
 
 
@@ -148,6 +153,16 @@ def systemctl_is_masked(unit_pattern):
     return False
 
 
+def systemctl_is_installed(unit_pattern):
+    '''Return True if returncode is other than "not-found" (4)'''
+    res = subprocess.run(['systemctl', 'is-enabled', unit_pattern],
+                         stdout=subprocess.PIPE, stderr=subprocess.PIPE,
+                         text=True)
+    if res.returncode != 4:
+        return True
+    return False
+
+
 def systemctl_daemon_reload():
     '''Reload systemd unit files from disk and re-calculate its dependencies'''
     subprocess.check_call(['systemctl', 'daemon-reload'])
@@ -203,6 +218,33 @@ def find_matching_iface(interfaces: list, netdef):
     return matches[0]
 
 
+def is_valid_macaddress(macaddress: str) -> bool:
+    MAC_PATTERN = '^[a-fA-F0-9][a-fA-F0-9](:[a-fA-F0-9][a-fA-F0-9]){5}((:[a-fA-F0-9][a-fA-F0-9]){14})?$'
+    return re.match(MAC_PATTERN, macaddress) is not None
+
+
+def route_table_lookup() -> dict:
+    lookup_table = {}
+    path = NEW_RT_TABLES_PATH
+
+    if not os.path.exists(path):
+        path = OLD_RT_TABLES_PATH
+
+    try:
+        with open(path, 'r') as rt_tables:
+            for line in rt_tables:
+                split_line = line.split()
+                if len(split_line) == 2 and split_line[0].isnumeric():
+                    lookup_table[int(split_line[0])] = split_line[1]
+                    lookup_table[split_line[1]] = int(split_line[0])
+    except Exception:
+        logging.debug(f'Cannot open \'{path}\' for reading')
+        # defaults to the standard content found in the file
+        return RT_TABLES_DEFAULT
+
+    return lookup_table
+
+
 class NetplanCommand(argparse.Namespace):
 
     def __init__(self, command_id, description, leaf=True, testing=False):
