@@ -152,11 +152,3 @@ NAME_FUNCTION_FLAGS(vxlan_extension);
 }
 
 ENUM_FUNCTION(def_type, NetplanDefType);
-
-/* ABI compatibility definitions */
-
-NETPLAN_ABI const char*
-tunnel_mode_to_string(NetplanTunnelMode val) __attribute__ ((alias ("netplan_tunnel_mode_name")));
-
-NETPLAN_ABI extern const char*
-netplan_backend_to_name __attribute__((alias("netplan_backend_to_str")));
