@@ -31,7 +31,6 @@
 #include "netplan.h"
 #include "nm.h"
 #include "parse.h"
-#include "parse-globals.h"
 #include "parse-nm.h"
 #include "util.h"
 #include "util-internal.h"
@@ -42,7 +41,7 @@
  * This is done by checking for certain modem_params, which are only
  * applicable to GSM connections.
  */
-static gboolean
+STATIC gboolean
 modem_is_gsm(const NetplanNetDefinition* def)
 {
     if (   def->modem_params.apn
@@ -60,7 +59,7 @@ modem_is_gsm(const NetplanNetDefinition* def)
 /**
  * Return NM "type=" string.
  */
-static char*
+STATIC char*
 type_str(const NetplanNetDefinition* def)
 {
     const NetplanDefType type = def->type;
@@ -111,7 +110,7 @@ type_str(const NetplanNetDefinition* def)
 /**
  * Return NM wifi "mode=" string.
  */
-static char*
+STATIC char*
 wifi_mode_str(const NetplanWifiMode mode)
 {
     switch (mode) {
@@ -131,7 +130,7 @@ wifi_mode_str(const NetplanWifiMode mode)
 /**
  * Return NM wifi "band=" string.
  */
-static char*
+STATIC char*
 wifi_band_str(const NetplanWifiBand band)
 {
     switch (band) {
@@ -149,7 +148,7 @@ wifi_band_str(const NetplanWifiBand band)
 /**
  * Return NM addr-gen-mode string.
  */
-static char*
+STATIC char*
 addr_gen_mode_str(const NetplanAddrGenMode mode)
 {
     switch (mode) {
@@ -164,7 +163,7 @@ addr_gen_mode_str(const NetplanAddrGenMode mode)
     }
 }
 
-static void
+STATIC void
 write_search_domains(const NetplanNetDefinition* def, const char* group, GKeyFile *kf)
 {
     if (def->search_domains) {
@@ -175,7 +174,7 @@ write_search_domains(const NetplanNetDefinition* def, const char* group, GKeyFil
     }
 }
 
-static gboolean
+STATIC gboolean
 write_routes_nm(const NetplanNetDefinition* def, GKeyFile *kf, gint family, GError** error)
 {
     const gchar* group = NULL;
@@ -255,8 +254,8 @@ write_routes_nm(const NetplanNetDefinition* def, GKeyFile *kf, gint family, GErr
     return TRUE;
 }
 
-static void
-write_bond_parameters(const NetplanNetDefinition* def, GKeyFile *kf)
+STATIC void
+write_nm_bond_parameters(const NetplanNetDefinition* def, GKeyFile *kf)
 {
     GString* tmp_val = NULL;
     if (def->bond_params.mode)
@@ -313,7 +312,7 @@ write_bond_parameters(const NetplanNetDefinition* def, GKeyFile *kf)
         g_key_file_set_string(kf, "bond", "primary", def->bond_params.primary_member);
 }
 
-static void
+STATIC void
 write_bridge_params_nm(const NetplanNetDefinition* def, GKeyFile *kf)
 {
     if (def->custom_bridging) {
@@ -331,8 +330,8 @@ write_bridge_params_nm(const NetplanNetDefinition* def, GKeyFile *kf)
     }
 }
 
-static gboolean
-write_wireguard_params(const NetplanNetDefinition* def, GKeyFile *kf, GError** error)
+STATIC gboolean
+write_nm_wireguard_params(const NetplanNetDefinition* def, GKeyFile *kf, GError** error)
 {
     /* The key was already validated via validate_tunnel_grammar(), but we need
      * to differentiate between base64 key VS absolute path key-file. And a base64
@@ -389,8 +388,8 @@ write_wireguard_params(const NetplanNetDefinition* def, GKeyFile *kf, GError** e
     return TRUE;
 }
 
-static void
-write_tunnel_params(const NetplanNetDefinition* def, GKeyFile *kf)
+STATIC void
+write_nm_tunnel_params(const NetplanNetDefinition* def, GKeyFile *kf)
 {
     g_key_file_set_integer(kf, "ip-tunnel", "mode", def->tunnel.mode);
     if (def->tunnel.local_ip)
@@ -404,7 +403,7 @@ write_tunnel_params(const NetplanNetDefinition* def, GKeyFile *kf)
         g_key_file_set_string(kf, "ip-tunnel", "output-key", def->tunnel.output_key);
 }
 
-static void
+STATIC void
 write_dot1x_auth_parameters(const NetplanAuthenticationSettings* auth, GKeyFile *kf)
 {
     switch (auth->eap_method) {
@@ -448,7 +447,7 @@ write_dot1x_auth_parameters(const NetplanAuthenticationSettings* auth, GKeyFile
         g_key_file_set_string(kf, "802-1x", "phase2-auth", auth->phase2_auth);
 }
 
-static void
+STATIC void
 write_wifi_auth_parameters(const NetplanAuthenticationSettings* auth, GKeyFile *kf)
 {
     switch (auth->key_management) {
@@ -498,15 +497,15 @@ write_wifi_auth_parameters(const NetplanAuthenticationSettings* auth, GKeyFile *
         g_key_file_set_string(kf, "wifi-security", "psk", auth->password);
 }
 
-static void
+STATIC void
 maybe_generate_uuid(const NetplanNetDefinition* def)
 {
     if (uuid_is_null(def->uuid))
         uuid_generate((unsigned char*)def->uuid);
 }
 
-static void
-write_vxlan_parameters(const NetplanNetDefinition* def, GKeyFile* kf)
+STATIC void
+write_nm_vxlan_parameters(const NetplanNetDefinition* def, GKeyFile* kf)
 {
     g_assert(def->vxlan);
     char uuidstr[37];
@@ -563,7 +562,7 @@ write_vxlan_parameters(const NetplanNetDefinition* def, GKeyFile* kf)
  * Special handling for passthrough mode: read key-value pairs from
  * "backend_settings.passthrough" and inject them into the keyfile as-is.
  */
-static void
+STATIC void
 write_fallback_key_value(GQuark key_id, gpointer value, gpointer user_data)
 {
     GKeyFile *kf = user_data;
@@ -620,7 +619,7 @@ write_fallback_key_value(GQuark key_id, gpointer value, gpointer user_data)
  * @ap: The access point for which to create a connection. Must be %NULL for
  *      non-wifi types.
  */
-static gboolean
+STATIC gboolean
 write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir, const NetplanWifiAccessPoint* ap, GError** error)
 {
     g_autoptr(GKeyFile) kf = NULL;
@@ -759,6 +758,8 @@ write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir,
             g_key_file_set_uint64(kf, "bridge-port", "path-cost", def->bridge_params.path_cost);
         if (def->bridge_params.port_priority)
             g_key_file_set_uint64(kf, "bridge-port", "priority", def->bridge_params.port_priority);
+        if (def->bridge_hairpin != NETPLAN_TRISTATE_UNSET)
+            g_key_file_set_boolean(kf, "bridge-port", "hairpin-mode", def->bridge_hairpin);
     }
     if (def->bond) {
         g_key_file_set_string(kf, "connection", "slave-type", "bond"); /* wokeignore:rule=slave */
@@ -815,16 +816,16 @@ write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir,
     }
 
     if (def->type == NETPLAN_DEF_TYPE_BOND)
-        write_bond_parameters(def, kf);
+        write_nm_bond_parameters(def, kf);
 
     if (def->type == NETPLAN_DEF_TYPE_TUNNEL) {
         if (def->tunnel.mode == NETPLAN_TUNNEL_MODE_WIREGUARD) {
-            if (!write_wireguard_params(def, kf, error))
+            if (!write_nm_wireguard_params(def, kf, error))
                 return FALSE;
         } else if (def->tunnel.mode == NETPLAN_TUNNEL_MODE_VXLAN) {
-            write_vxlan_parameters(def, kf);
+            write_nm_vxlan_parameters(def, kf);
         } else
-            write_tunnel_params(def, kf);
+            write_nm_tunnel_params(def, kf);
     }
 
     if (match_interface_name) {
@@ -976,17 +977,17 @@ write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir,
     }
 
     /* Create /run/NetworkManager/ with 755 permissions if the folder is missing.
-     * Letting the next invokation of safe_mkdir_p_dir do it would result in 
-     * more restrictive access because of the call to umask. */
+     * Letting the next invokation of _netplan_safe_mkdir_p_dir do it would
+     * result in more restrictive access because of the call to umask. */
     nm_run_path = g_strjoin(G_DIR_SEPARATOR_S, rootdir ?: "", "run/NetworkManager/", NULL);
     if (!g_file_test(nm_run_path, G_FILE_TEST_EXISTS))
-        safe_mkdir_p_dir(nm_run_path);
+        _netplan_safe_mkdir_p_dir(nm_run_path);
 
     full_path = g_strjoin(G_DIR_SEPARATOR_S, rootdir ?: "", conf_path, NULL);
 
     /* NM connection files might contain secrets, and NM insists on tight permissions */
     orig_umask = umask(077);
-    safe_mkdir_p_dir(full_path);
+    _netplan_safe_mkdir_p_dir(full_path);
     if (!g_key_file_save_to_file(kf, full_path, error))
         return FALSE; // LCOV_EXCL_LINE
     umask(orig_umask);
@@ -1000,7 +1001,7 @@ write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir,
  *           (useful for testing).
  */
 gboolean
-netplan_netdef_write_nm(
+_netplan_netdef_write_nm(
         __unused const NetplanState* np_state,
         const NetplanNetDefinition* netdef,
         const char* rootdir,
@@ -1105,7 +1106,7 @@ netplan_state_finish_nm_write(
                 g_string_append_printf(udev_rules, "%s ENV{ID_NET_NAME}==\"%s\",%s", prefix, nd->id, suffix);
             }
             /* Also, match by explicit (new) MAC, if available */
-            if (nd->set_mac) {
+            if (nd->set_mac && _is_valid_macaddress(nd->set_mac)) {
                 tmp = g_string_new(nd->set_mac);
                 g_string_append_printf(udev_rules, "%s ATTR{address}==\"%s\",%s", prefix, g_string_ascii_down(tmp)->str, suffix);
                 g_string_free(tmp, TRUE);
@@ -1149,13 +1150,13 @@ netplan_state_finish_nm_write(
 
     /* write generated NetworkManager drop-in config */
     if (nm_conf->len > 0)
-        g_string_free_to_file(nm_conf, rootdir, "run/NetworkManager/conf.d/netplan.conf", NULL);
+        _netplan_g_string_free_to_file(nm_conf, rootdir, "run/NetworkManager/conf.d/netplan.conf", NULL);
     else
         g_string_free(nm_conf, TRUE);
 
     /* write generated udev rules */
     if (udev_rules->len > 0)
-        g_string_free_to_file(udev_rules, rootdir, "run/udev/rules.d/90-netplan.rules", NULL);
+        _netplan_g_string_free_to_file(udev_rules, rootdir, "run/udev/rules.d/90-netplan.rules", NULL);
     else
         g_string_free(udev_rules, TRUE);
 
@@ -1166,12 +1167,12 @@ netplan_state_finish_nm_write(
  * Clean up all generated configurations in @rootdir from previous runs.
  */
 gboolean
-netplan_nm_cleanup(const char* rootdir)
+_netplan_nm_cleanup(const char* rootdir)
 {
     g_autofree char* confpath = g_strjoin(NULL, rootdir ?: "", "/run/NetworkManager/conf.d/netplan.conf", NULL);
     g_autofree char* global_manage_path = g_strjoin(NULL, rootdir ?: "", "/run/NetworkManager/conf.d/10-globally-managed-devices.conf", NULL);
     unlink(confpath);
     unlink(global_manage_path);
-    unlink_glob(rootdir, "/run/NetworkManager/system-connections/netplan-*");
+    _netplan_unlink_glob(rootdir, "/run/NetworkManager/system-connections/netplan-*");
     return TRUE;
 }
