@@ -25,11 +25,10 @@
 #include "openvswitch.h"
 #include "networkd.h"
 #include "parse.h"
-#include "parse-globals.h"
 #include "util.h"
 #include "util-internal.h"
 
-static gboolean
+STATIC gboolean
 write_ovs_systemd_unit(const char* id, const GString* cmds, const char* rootdir, gboolean physical, gboolean cleanup, const char* dependency, GError** error)
 {
     g_autofree gchar* id_escaped = NULL;
@@ -60,11 +59,16 @@ write_ovs_systemd_unit(const char* id, const GString* cmds, const char* rootdir,
     }
 
     g_string_append(s, "\n[Service]\nType=oneshot\nTimeoutStartSec=10s\n");
+    /* During tests the rate in which the netplan-ovs-cleanup service is started/stopped
+     * might exceed StartLimitBurst.
+     */
+    if (cleanup)
+        g_string_append(s, "StartLimitBurst=0\n");
     g_string_append(s, cmds->str);
 
-    g_string_free_to_file(s, rootdir, path, NULL);
+    _netplan_g_string_free_to_file(s, rootdir, path, NULL);
 
-    safe_mkdir_p_dir(link);
+    _netplan_safe_mkdir_p_dir(link);
     if (symlink(path, link) < 0 && errno != EEXIST) {
         // LCOV_EXCL_START
         g_set_error(error, NETPLAN_FILE_ERROR, errno, "failed to create enablement symlink: %m\n");
@@ -81,7 +85,7 @@ write_ovs_systemd_unit(const char* id, const GString* cmds, const char* rootdir,
     g_string_append(s, "\n"); \
 }
 
-static char*
+STATIC char*
 netplan_type_to_table_name(const NetplanDefType type)
 {
     switch (type) {
@@ -95,7 +99,7 @@ netplan_type_to_table_name(const NetplanDefType type)
     }
 }
 
-static gboolean
+STATIC gboolean
 netplan_type_is_physical(const NetplanDefType type)
 {
     switch (type) {
@@ -108,7 +112,7 @@ netplan_type_is_physical(const NetplanDefType type)
     }
 }
 
-static void
+STATIC void
 write_ovs_tag_setting(const gchar* id, const char* type, const char* col, const char* key, const char* value, GString* cmds)
 {
     g_assert(col);
@@ -131,7 +135,7 @@ write_ovs_tag_setting(const gchar* id, const char* type, const char* col, const
     g_string_free(s, TRUE);
 }
 
-static void
+STATIC void
 write_ovs_additional_data(GHashTable *data, const char* type, const gchar* id, GString* cmds, const char* setting)
 {
     GHashTableIter iter;
@@ -148,7 +152,7 @@ write_ovs_additional_data(GHashTable *data, const char* type, const gchar* id, G
     }
 }
 
-static void
+STATIC void
 setup_patch_port(GString* s, const NetplanNetDefinition* def)
 {
     /* Execute the setup commands to create an OVS patch port atomically within
@@ -160,7 +164,7 @@ setup_patch_port(GString* s, const NetplanNetDefinition* def)
                            def->id, def->peer);
 }
 
-static char*
+STATIC char*
 write_ovs_bond_interfaces(const NetplanState* np_state, const NetplanNetDefinition* def, GString* cmds, GError** error)
 {
     NetplanNetDefinition* tmp_nd;
@@ -198,7 +202,7 @@ write_ovs_bond_interfaces(const NetplanState* np_state, const NetplanNetDefiniti
     return def->bridge;
 }
 
-static void
+STATIC void
 write_ovs_tag_netplan(const gchar* id, const char* type, GString* cmds)
 {
     /* Mark this bridge/port/interface as created by netplan */
@@ -206,7 +210,7 @@ write_ovs_tag_netplan(const gchar* id, const char* type, GString* cmds)
                        type, id);
 }
 
-static gboolean
+STATIC gboolean
 write_ovs_bond_mode(const NetplanNetDefinition* def, GString* cmds, GError** error)
 {
     char* value = NULL;
@@ -226,7 +230,7 @@ write_ovs_bond_mode(const NetplanNetDefinition* def, GString* cmds, GError** err
     return TRUE;
 }
 
-static void
+STATIC void
 write_ovs_bridge_interfaces(const NetplanState* np_state, const NetplanNetDefinition* def, GString* cmds)
 {
     NetplanNetDefinition* tmp_nd;
@@ -250,7 +254,7 @@ write_ovs_bridge_interfaces(const NetplanState* np_state, const NetplanNetDefini
     }
 }
 
-static void
+STATIC void
 write_ovs_protocols(const NetplanOVSSettings* ovs_settings, const gchar* bridge, GString* cmds)
 {
     g_assert(bridge);
@@ -264,7 +268,7 @@ write_ovs_protocols(const NetplanOVSSettings* ovs_settings, const gchar* bridge,
     g_string_free(s, TRUE);
 }
 
-static gboolean
+STATIC gboolean
 check_ovs_ssl(const NetplanOVSSettings* settings, gchar* target, gboolean* needs_ssl, GError** error)
 {
     /* Check if target needs ssl */
@@ -282,7 +286,7 @@ check_ovs_ssl(const NetplanOVSSettings* settings, gchar* target, gboolean* needs
     return TRUE;
 }
 
-static gboolean
+STATIC gboolean
 write_ovs_bridge_controller_targets(const NetplanOVSSettings* settings, const NetplanOVSController* controller, const gchar* bridge, GString* cmds, GError** error)
 {
     gchar* target = g_array_index(controller->addresses, char*, 0);
@@ -315,7 +319,7 @@ cleanup:
  *           (useful for testing).
  */
 gboolean
-netplan_netdef_write_ovs(const NetplanState* np_state, const NetplanNetDefinition* def, const char* rootdir, gboolean* has_been_written, GError** error)
+_netplan_netdef_write_ovs(const NetplanState* np_state, const NetplanNetDefinition* def, const char* rootdir, gboolean* has_been_written, GError** error)
 {
     g_autoptr(GString) cmds = g_string_new(NULL);
     gchar* dependency = NULL;
@@ -412,7 +416,7 @@ netplan_netdef_write_ovs(const NetplanState* np_state, const NetplanNetDefinitio
         /* Try writing out a base config */
         /* TODO: make use of netplan_netdef_get_output_filename() */
         base_config_path = g_strjoin(NULL, "run/systemd/network/10-netplan-", def->id, NULL);
-        if (!netplan_netdef_write_network_file(np_state, def, rootdir, base_config_path, has_been_written, error))
+        if (!_netplan_netdef_write_network_file(np_state, def, rootdir, base_config_path, has_been_written, error))
             return FALSE;
     } else {
         /* Other interfaces must be part of an OVS bridge or bond to carry additional data */
@@ -502,9 +506,9 @@ netplan_state_finish_ovs_write(const NetplanState* np_state, const char* rootdir
  */
 
 gboolean
-netplan_ovs_cleanup(const char* rootdir)
+_netplan_ovs_cleanup(const char* rootdir)
 {
-    unlink_glob(rootdir, "/run/systemd/system/systemd-networkd.service.wants/netplan-ovs-*.service");
-    unlink_glob(rootdir, "/run/systemd/system/netplan-ovs-*.service");
+    _netplan_unlink_glob(rootdir, "/run/systemd/system/systemd-networkd.service.wants/netplan-ovs-*.service");
+    _netplan_unlink_glob(rootdir, "/run/systemd/system/netplan-ovs-*.service");
     return TRUE;
 }
