@@ -29,7 +29,7 @@
 /* Helper function to free a GArray after applying a destructor to its
  * elements. Note that in the most trivial case (g_free) we should probably
  * have used a GPtrArray directly... */
-static void
+STATIC void
 free_garray_with_destructor(GArray** array, void (destructor)(void *))
 {
     if (*array) {
@@ -44,7 +44,7 @@ free_garray_with_destructor(GArray** array, void (destructor)(void *))
 
 /* Helper function to free a GHashTable after applying a simple destructor to its
  * elements. */
-static void
+STATIC void
 free_hashtable_with_destructor(GHashTable** hash, void (destructor)(void *)) {
     if (*hash) {
         GHashTableIter iter;
@@ -69,7 +69,7 @@ free_address_options(void* ptr)
     g_free(opts);
 }
 
-static void
+STATIC void
 free_route(void* ptr)
 {
     NetplanIPRoute* route = ptr;
@@ -81,7 +81,7 @@ free_route(void* ptr)
     g_free(route);
 }
 
-static void
+STATIC void
 free_ip_rules(void* ptr)
 {
     NetplanIPRule* rule = ptr;
@@ -90,7 +90,7 @@ free_ip_rules(void* ptr)
     g_free(rule);
 }
 
-static void
+STATIC void
 free_wireguard_peer(void* ptr)
 {
     NetplanWireguardPeer* wg = ptr;
@@ -101,7 +101,7 @@ free_wireguard_peer(void* ptr)
     g_free(wg);
 }
 
-static void
+STATIC void
 reset_auth_settings(NetplanAuthenticationSettings* auth)
 {
     FREE_AND_NULLIFY(auth->identity);
@@ -137,7 +137,7 @@ reset_ovs_settings(NetplanOVSSettings* settings)
     FREE_AND_NULLIFY(settings->controller.connection_mode);
 }
 
-static void
+STATIC void
 reset_dhcp_overrides(NetplanDHCPOverrides* overrides)
 {
     overrides->use_dns = TRUE;
@@ -162,7 +162,7 @@ reset_ip_rule(NetplanIPRule* ip_rule)
 }
 
 /* Reset a backend settings object. */
-static void
+STATIC void
 reset_backend_settings(NetplanBackendSettings* settings)
 {
     FREE_AND_NULLIFY(settings->name);
@@ -172,7 +172,7 @@ reset_backend_settings(NetplanBackendSettings* settings)
     g_datalist_clear(&settings->passthrough);
 }
 
-static void
+STATIC void
 reset_private_netdef_data(struct private_netdef_data* data) {
     if (!data)
         return;
@@ -323,6 +323,8 @@ reset_netdef(NetplanNetDefinition* netdef, NetplanDefType new_type, NetplanBacke
     FREE_AND_NULLIFY(netdef->modem_params.username);
     memset(&netdef->modem_params, 0, sizeof(netdef->modem_params));
 
+    netdef->bridge_hairpin = NETPLAN_TRISTATE_UNSET;
+    netdef->bridge_learning = NETPLAN_TRISTATE_UNSET;
     netdef->bridge_neigh_suppress = NETPLAN_TRISTATE_UNSET;
     FREE_AND_NULLIFY(netdef->bridge_params.ageing_time);
     FREE_AND_NULLIFY(netdef->bridge_params.forward_delay);
@@ -516,9 +518,6 @@ netplan_netdef_get_vlan_link(const NetplanNetDefinition* netdef)
     return netdef->vlan_link;
 }
 
-__attribute((alias("netplan_netdef_get_vlan_link"))) NETPLAN_INTERNAL NetplanNetDefinition*
-_netplan_netdef_get_vlan_link(const NetplanNetDefinition* netdef);
-
 NetplanNetDefinition*
 netplan_netdef_get_sriov_link(const NetplanNetDefinition* netdef)
 {
@@ -526,9 +525,6 @@ netplan_netdef_get_sriov_link(const NetplanNetDefinition* netdef)
     return netdef->sriov_link;
 }
 
-__attribute((alias("netplan_netdef_get_sriov_link"))) NETPLAN_INTERNAL NetplanNetDefinition*
-_netplan_netdef_get_sriov_link(const NetplanNetDefinition* netdef);
-
 NetplanNetDefinition*
 netplan_netdef_get_bridge_link(const NetplanNetDefinition* netdef)
 {
@@ -536,6 +532,13 @@ netplan_netdef_get_bridge_link(const NetplanNetDefinition* netdef)
     return netdef->bridge_link;
 }
 
+NetplanNetDefinition*
+netplan_netdef_get_vrf_link(const NetplanNetDefinition* netdef)
+{
+    g_assert(netdef);
+    return netdef->vrf_link;
+}
+
 NetplanNetDefinition*
 netplan_netdef_get_bond_link(const NetplanNetDefinition* netdef)
 {
@@ -565,15 +568,12 @@ _netplan_netdef_get_embedded_switch_mode(const NetplanNetDefinition* netdef, cha
 }
 
 gboolean
-_netplan_netdef_get_delay_vf_rebind(const NetplanNetDefinition* netdef)
+_netplan_netdef_get_delay_virtual_functions_rebind(const NetplanNetDefinition* netdef)
 {
     g_assert(netdef);
     return netdef->sriov_delay_virtual_functions_rebind;
 }
 
-__attribute((alias("_netplan_netdef_get_delay_vf_rebind"))) NETPLAN_INTERNAL gboolean
-netplan_netdef_get_delay_virtual_functions_rebind(const NetplanNetDefinition* netdef);
-
 gboolean
 netplan_netdef_has_match(const NetplanNetDefinition* netdef)
 {
@@ -619,3 +619,14 @@ _netplan_netdef_is_trivial_compound_itf(const NetplanNetDefinition* netdef)
         return !complex_object_is_dirty(netdef, &netdef->bridge_params, sizeof(netdef->bridge_params));
     return FALSE;
 }
+
+ssize_t
+_netplan_netdef_get_bond_mode(const NetplanNetDefinition* netdef, char* out_buffer, size_t out_buf_size)
+{
+    g_assert(netdef);
+
+    if (netdef->type == NETPLAN_DEF_TYPE_BOND && netdef->bond_params.mode)
+        return netplan_copy_string(netdef->bond_params.mode, out_buffer, out_buf_size);
+    else
+        return FALSE;
+}
