@@ -34,31 +34,31 @@ wifi_frequency_24;
 extern GHashTable*
 wifi_frequency_5;
 
-NETPLAN_ABI void
-safe_mkdir_p_dir(const char* file_path);
+NETPLAN_INTERNAL void
+_netplan_safe_mkdir_p_dir(const char* file_path);
 
 NETPLAN_INTERNAL void
-g_string_free_to_file(GString* s, const char* rootdir, const char* path, const char* suffix);
+_netplan_g_string_free_to_file(GString* s, const char* rootdir, const char* path, const char* suffix);
 
 NETPLAN_INTERNAL void
-unlink_glob(const char* rootdir, const char* _glob);
+_netplan_unlink_glob(const char* rootdir, const char* _glob);
 
 NETPLAN_INTERNAL int
-find_yaml_glob(const char* rootdir, glob_t* out_glob);
+_netplan_find_yaml_glob(const char* rootdir, glob_t* out_glob);
 
-NETPLAN_ABI const char*
+const char*
 get_global_network(int ip_family);
 
-NETPLAN_ABI const char*
+const char*
 get_unspecified_address(int ip_family);
 
-NETPLAN_ABI int
+int
 wifi_get_freq24(int channel);
 
-NETPLAN_ABI int
+int
 wifi_get_freq5(int channel);
 
-NETPLAN_ABI gchar*
+gchar*
 systemd_escape(char* string);
 
 #define OPENVSWITCH_OVS_VSCTL "/usr/bin/ovs-vsctl"
@@ -78,12 +78,6 @@ netplan_netdef_new(NetplanParser* npp, const char* id, NetplanDefType type, Netp
 const char *
 netplan_parser_get_filename(NetplanParser* npp);
 
-NETPLAN_INTERNAL void
-process_input_file(const char* f);
-
-NETPLAN_INTERNAL gboolean
-process_yaml_hierarchy(const char* rootdir);
-
 gboolean
 has_openvswitch(const NetplanOVSSettings* ovs, NetplanBackend backend, GHashTable *ovs_ports);
 
@@ -112,29 +106,38 @@ NETPLAN_INTERNAL ssize_t
 _netplan_netdef_get_embedded_switch_mode(const NetplanNetDefinition* netdef, char* out_buffer, size_t out_buf_size);
 
 NETPLAN_INTERNAL gboolean
-_netplan_netdef_get_delay_vf_rebind(const NetplanNetDefinition* netdef);
-
-NETPLAN_INTERNAL gboolean
-netplan_netdef_get_delay_virtual_functions_rebind(const NetplanNetDefinition* netdef);
+_netplan_netdef_get_delay_virtual_functions_rebind(const NetplanNetDefinition* netdef);
 
 NETPLAN_INTERNAL guint
 _netplan_netdef_get_vlan_id(const NetplanNetDefinition* netdef);
 
+NETPLAN_INTERNAL ssize_t
+_netplan_netdef_get_bond_mode(const NetplanNetDefinition* netdef, char* out_buffer, size_t out_buf_size);
+
 NETPLAN_INTERNAL gboolean
 _netplan_netdef_is_trivial_compound_itf(const NetplanNetDefinition* netdef);
 
-NETPLAN_INTERNAL gboolean //FIXME: avoid exporting private symbol
+gboolean
 is_route_present(const NetplanNetDefinition* netdef, const NetplanIPRoute* route);
 
-NETPLAN_INTERNAL gboolean //FIXME: avoid exporting private symbol
+gboolean
 is_route_rule_present(const NetplanNetDefinition* netdef, const NetplanIPRule* rule);
 
-NETPLAN_INTERNAL gboolean //FIXME: avoid exporting private symbol
+gboolean
 is_string_in_array(GArray* array, const char* value);
 
 gboolean
 _is_auth_key_management_psk(const NetplanAuthenticationSettings* auth);
 
+gboolean
+_is_macaddress_special_nm_option(const char* value);
+
+gboolean
+_is_macaddress_special_nd_option(const char* value);
+
+gboolean
+_is_valid_macaddress(const char* value);
+
 NETPLAN_INTERNAL struct address_iter*
 _netplan_netdef_new_address_iter(NetplanNetDefinition* netdef);
 
