@@ -20,6 +20,7 @@
 #include <arpa/inet.h>
 #include <fnmatch.h>
 #include <errno.h>
+#include <regex.h>
 #include <string.h>
 #include <sys/mman.h>
 
@@ -31,14 +32,13 @@
 #include "util-internal.h"
 #include "netplan.h"
 #include "parse.h"
-#include "parse-globals.h"
 #include "names.h"
 #include "yaml-helpers.h"
 
-NETPLAN_ABI GHashTable*
+GHashTable*
 wifi_frequency_24;
 
-NETPLAN_ABI GHashTable*
+GHashTable*
 wifi_frequency_5;
 
 const gchar* FALLBACK_FILENAME = "70-netplan-set.yaml";
@@ -48,7 +48,7 @@ typedef struct netplan_state_iterator RealStateIter;
  * Create the parent directories of given file path. Exit program on failure.
  */
 void
-safe_mkdir_p_dir(const char* file_path)
+_netplan_safe_mkdir_p_dir(const char* file_path)
 {
     g_autofree char* dir = g_path_get_dirname(file_path);
 
@@ -66,7 +66,7 @@ safe_mkdir_p_dir(const char* file_path)
  * @path: path of file to write (@rootdir will be prepended)
  * @suffix: optional suffix to append to path
  */
-void g_string_free_to_file(GString* s, const char* rootdir, const char* path, const char* suffix)
+void _netplan_g_string_free_to_file(GString* s, const char* rootdir, const char* path, const char* suffix)
 {
     g_autofree char* full_path = NULL;
     g_autofree char* path_suffix = NULL;
@@ -75,7 +75,7 @@ void g_string_free_to_file(GString* s, const char* rootdir, const char* path, co
 
     path_suffix = g_strjoin(NULL, path, suffix, NULL);
     full_path = g_build_path(G_DIR_SEPARATOR_S, rootdir ?: G_DIR_SEPARATOR_S, path_suffix, NULL);
-    safe_mkdir_p_dir(full_path);
+    _netplan_safe_mkdir_p_dir(full_path);
     if (!g_file_set_contents(full_path, contents, -1, &error)) {
         /* the mkdir() just succeeded, there is no sensible
          * method to test this without root privileges, bind mounts, and
@@ -91,7 +91,7 @@ void g_string_free_to_file(GString* s, const char* rootdir, const char* path, co
  * Remove all files matching given glob.
  */
 void
-unlink_glob(const char* rootdir, const char* _glob)
+_netplan_unlink_glob(const char* rootdir, const char* _glob)
 {
     glob_t gl;
     int rc;
@@ -113,7 +113,7 @@ unlink_glob(const char* rootdir, const char* _glob)
 /**
  * Return a glob of all *.yaml files in /{lib,etc,run}/netplan/ (in this order)
  */
-int find_yaml_glob(const char* rootdir, glob_t* out_glob)
+int _netplan_find_yaml_glob(const char* rootdir, glob_t* out_glob)
 {
     int rc;
     g_autofree char* rglob = g_build_path(G_DIR_SEPARATOR_S,
@@ -130,20 +130,6 @@ int find_yaml_glob(const char* rootdir, glob_t* out_glob)
     return 0;
 }
 
-
-/**
- * create a yaml patch from a "set expression"
- *
- * A "set expression" here consists of a path formed of TAB-separated
- * keys, indicating where in the YAML doc we want to make our changes, and
- * a valid YAML expression that will be the payload to insert at that
- * place. The result is a well-formed YAML document.
- *
- * @conf_obj_path: TAB-separated YAML path
- * @obj_payload: YAML expression
- * @output_file: file path to write out the result document
- */
-
 gboolean
 netplan_util_create_yaml_patch(const char* conf_obj_path, const char* obj_payload, int output_fd, GError** error)
 {
@@ -238,7 +224,7 @@ file_error:
 // LCOV_EXCL_STOP
 }
 
-static gboolean
+STATIC gboolean
 copy_yaml_subtree(yaml_parser_t *parser, yaml_emitter_t *emitter, GError** error) {
 	yaml_event_t event;
     int map_count = 0, seq_count = 0;
@@ -278,7 +264,7 @@ copy_yaml_subtree(yaml_parser_t *parser, yaml_emitter_t *emitter, GError** error
  * Given a YAML tree and a YAML path (array of keys with NULL as the last array element),
  * emits the subtree matching the path, while emitting the rest of the data into the void.
  */
-static gboolean
+STATIC gboolean
 emit_yaml_subtree(yaml_parser_t *parser, yaml_emitter_t *emitter, char** yaml_path, GError** error) {
 	yaml_event_t event;
     /* If the path component is NULL, we're done with the trimming, we can just copy the whole subtree */
@@ -586,20 +572,6 @@ cleanup:
     return ret;
 }
 
-gboolean
-netplan_generate(const char* rootdir)
-{
-    /* TODO: refactor logic to actually be inside the library instead of spawning another process */
-    const gchar *argv[] = { SBINDIR "/" "netplan", "generate", NULL , NULL, NULL };
-    if (rootdir) {
-        argv[2] = "--root-dir";
-        argv[3] = rootdir;
-    }
-    if (getenv("TEST_NETPLAN_CMD") != 0)
-       argv[0] = getenv("TEST_NETPLAN_CMD");
-    return g_spawn_sync(NULL, (gchar**)argv, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
-}
-
 /**
  * Extract the netplan netdef ID from a NetworkManager connection profile (keyfile),
  * generated by netplan. Used by the NetworkManager YAML backend.
@@ -674,7 +646,7 @@ netplan_parser_load_yaml_hierarchy(NetplanParser* npp, const char* rootdir, GErr
      * To do that, we put all found files in a hash table, then sort it by
      * file name, and add the entries from /run after the ones from /etc
      * and those after the ones from /lib. */
-    if (find_yaml_glob(rootdir, &gl) != 0)
+    if (_netplan_find_yaml_glob(rootdir, &gl) != 0)
         return FALSE; // LCOV_EXCL_LINE
     /* keys are strdup()ed, free them; values point into the glob_t, don't free them */
     g_autoptr(GHashTable) configs = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
@@ -884,7 +856,6 @@ _netplan_state_new_netdef_pertype_iter(NetplanState* np_state, const char* def_t
     return iter;
 }
 
-
 NetplanNetDefinition*
 _netplan_netdef_pertype_iter_next(struct netdef_pertype_iter* it)
 {
@@ -909,12 +880,6 @@ _netplan_netdef_pertype_iter_free(struct netdef_pertype_iter* it)
     g_free(it);
 }
 
-__attribute((alias("_netplan_netdef_pertype_iter_next"))) NETPLAN_ABI NetplanNetDefinition*
-_netplan_iter_defs_per_devtype_next(struct netdef_pertype_iter* it);
-
-__attribute((alias("_netplan_netdef_pertype_iter_free"))) NETPLAN_ABI void
-_netplan_iter_defs_per_devtype_free(struct netdef_pertype_iter* it);
-
 gboolean
 has_openvswitch(const NetplanOVSSettings* ovs, NetplanBackend backend, GHashTable *ovs_ports)
 {
@@ -1042,6 +1007,18 @@ netplan_netdef_get_dhcp6(const NetplanNetDefinition* netdef)
     return netdef->dhcp6;
 }
 
+gboolean
+netplan_netdef_get_link_local_ipv4(const NetplanNetDefinition* netdef)
+{
+    return netdef->linklocal.ipv4;
+}
+
+gboolean
+netplan_netdef_get_link_local_ipv6(const NetplanNetDefinition* netdef)
+{
+    return netdef->linklocal.ipv6;
+}
+
 gboolean
 is_multicast_address(const char* address)
 {
@@ -1091,7 +1068,7 @@ netplan_state_iterator_has_next(const NetplanStateIterator* iter)
     return _iter->next != NULL;
 }
 
-static const char*
+STATIC const char*
 normalize_ip_address(const char* addr, const guint family)
 {
     if (!g_strcmp0(addr, "default")) {
@@ -1177,3 +1154,33 @@ _is_auth_key_management_psk(const NetplanAuthenticationSettings* auth)
     return (   auth->key_management == NETPLAN_AUTH_KEY_MANAGEMENT_WPA_PSK
             || auth->key_management == NETPLAN_AUTH_KEY_MANAGEMENT_WPA_SAE);
 }
+
+gboolean
+_is_macaddress_special_nm_option(const char* value)
+{
+    return (   !g_strcmp0(value, "preserve")
+            || !g_strcmp0(value, "permanent")
+            || !g_strcmp0(value, "random")
+            || !g_strcmp0(value, "stable"));
+}
+
+gboolean
+_is_macaddress_special_nd_option(const char* value)
+{
+    return (   !g_strcmp0(value, "permanent")
+            || !g_strcmp0(value, "random"));
+}
+
+gboolean
+_is_valid_macaddress(const char* value)
+{
+    static regex_t re;
+    static gboolean re_inited = FALSE;
+
+    if (!re_inited) {
+        g_assert(regcomp(&re, "^[[:xdigit:]][[:xdigit:]](:[[:xdigit:]][[:xdigit:]]){5}((:[[:xdigit:]][[:xdigit:]]){14})?$", REG_EXTENDED|REG_NOSUB) == 0);
+        re_inited = TRUE;
+    }
+
+    return regexec(&re, value, 0, NULL, 0) == 0;
+}
