@@ -7,14 +7,7 @@
 
 #include "netplan.h"
 #include "parse.h"
-
-#include "error.c"
-#include "names.c"
-#include "netplan.c"
-#include "validation.c"
-#include "types.c"
-#include "util.c"
-#include "parse.c"
+#include "util-internal.h"
 
 #include "test_utils.h"
 
