@@ -32,6 +32,9 @@ import ctypes.util
 import yaml
 import difflib
 import re
+from io import StringIO
+
+import netplan
 
 exe_generate = os.environ.get('NETPLAN_GENERATE_PATH',
                               os.path.join(os.path.dirname(os.path.dirname(
@@ -43,7 +46,7 @@ os.environ.update({'LD_LIBRARY_PATH': '.:{}'.format(os.environ.get('LD_LIBRARY_P
 # make sure we fail on criticals
 os.environ['G_DEBUG'] = 'fatal-criticals'
 
-lib = ctypes.CDLL(ctypes.util.find_library('netplan'))
+lib = ctypes.CDLL('libnetplan.so.1')
 
 # common patterns for expected output
 ND_EMPTY = '[Match]\nName=%s\n\n[Network]\nLinkLocalAddressing=%s\nConfigureWithoutCarrier=yes\n'
@@ -70,7 +73,7 @@ rstp_enable=false\nExecStart=/usr/bin/ovs-vsctl set Bridge %(iface)s external-id
 OVS_BR_EMPTY = _OVS_BASE + 'After=netplan-ovs-cleanup.service\nBefore=network.target\nWants=network.target\n\n[Service]\n\
 Type=oneshot\nTimeoutStartSec=10s\nExecStart=/usr/bin/ovs-vsctl --may-exist add-br %(iface)s\n' + OVS_BR_DEFAULT
 OVS_CLEANUP = _OVS_BASE + 'ConditionFileIsExecutable=/usr/bin/ovs-vsctl\nBefore=network.target\nWants=network.target\n\n\
-[Service]\nType=oneshot\nTimeoutStartSec=10s\nExecStart=/usr/sbin/netplan apply --only-ovs-cleanup\n'
+[Service]\nType=oneshot\nTimeoutStartSec=10s\nStartLimitBurst=0\nExecStart=/usr/sbin/netplan apply --only-ovs-cleanup\n'
 UDEV_MAC_RULE = 'SUBSYSTEM=="net", ACTION=="add", DRIVERS=="%s", ATTR{address}=="%s", NAME="%s"\n'
 UDEV_NO_MAC_RULE = 'SUBSYSTEM=="net", ACTION=="add", DRIVERS=="%s", NAME="%s"\n'
 UDEV_SRIOV_RULE = 'ACTION=="add", SUBSYSTEM=="net", ATTRS{sriov_totalvfs}=="?*", RUN+="/usr/sbin/netplan apply --sriov-only"\n'
@@ -269,31 +272,33 @@ class TestBase(unittest.TestCase):
         original (and normalized) input with the generated (and normalized)
         output.
         '''
-        output = '_generated_test_output.yaml'
-        output_path = os.path.join(self.confdir, output)
 
         for input in yaml_input:
-            lib.netplan_clear_netdefs()  # clear previous netdefs
-            lib.netplan_parse_yaml(input.encode(), None)
-            lib.write_netplan_conf_full(output.encode(), self.workdir.name.encode())
+            parser = netplan.Parser()
+            parser.load_yaml(input)
+            state = netplan.State()
+            state.import_parser_results(parser)
 
-            input_yaml = None
-            output_yaml = None
+            # TODO: Allow handling of full hierarchy overrides,
+            #       dealing only with the current element of 'yaml_input'.
+            #       E.g. allow vlan.id & vlan.link to be defined in a base file.
+            #       See test_routing.py:
+            #       test_add_routes_to_different_tables_from_multiple_files
+            #       test_add_duplicate_routes_from_multiple_files
+
+            # Read output of the YAML generator (if any)
+            output_fd = StringIO()
+            state._dump_yaml(output_fd)
+            output_yaml = yaml.safe_load(output_fd.getvalue())
 
             # Read input YAML file, as defined by the self.generate('...') method
+            input_yaml = None
             with open(input, 'r') as orig:
                 input_yaml = yaml.safe_load(orig.read())
                 # Consider 'network: {}' and 'network: {version: 2}' to be empty
                 if input_yaml is None or input_yaml == {'network': {}} or input_yaml == {'network': {'version': 2}}:
                     input_yaml = yaml.safe_load('')
 
-            # Read output of the YAML generator (if any)
-            if os.path.isfile(output_path):
-                with open(output_path, 'r') as generated:
-                    output_yaml = yaml.safe_load(generated.read())
-            else:
-                output_yaml = yaml.safe_load('')
-
             # Normalize input and output YAML
             netplan_normalizer = NetplanV2Normalizer()
             input_lines = netplan_normalizer.normalize_yaml(input_yaml)
@@ -312,11 +317,6 @@ class TestBase(unittest.TestCase):
                     print(line, flush=True)
                 self.fail('Re-generated YAML file does not match (adopt netplan.c YAML generator?)')
 
-            # Cleanup the generated file and data structures
-            lib.netplan_clear_netdefs()
-            if os.path.isfile(output_path):
-                os.remove(output_path)
-
     def generate(self, yaml, expect_fail=False, extra_args=[], confs=None, skip_generated_yaml_validation=False):
         '''Call generate with given YAML string as configuration
 
@@ -378,12 +378,6 @@ class TestBase(unittest.TestCase):
             with open(os.path.join(networkd_dir, '10-netplan-' + fname)) as f:
                 self.assertEqual(f.read(), contents)
 
-    def assert_additional_udev(self, file_contents_map):
-        udev_dir = os.path.join(self.workdir.name, 'run', 'udev', 'rules.d')
-        for fname, contents in file_contents_map.items():
-            with open(os.path.join(udev_dir, fname)) as f:
-                self.assertEqual(f.read(), contents)
-
     def assert_networkd_udev(self, file_contents_map):
         udev_dir = os.path.join(self.workdir.name, 'run', 'udev', 'rules.d')
         if not file_contents_map:
@@ -491,3 +485,10 @@ class TestBase(unittest.TestCase):
         self.assertEqual(set(os.path.basename(file) for file in sriov_systemd_dir),
                          {'netplan-sriov-' + f for f in file_contents_map})
         self.assertEqual(set(os.listdir(self.workdir.name)) - {'lib'}, {'etc', 'run'})
+
+        for file in sriov_systemd_dir:
+            basename = os.path.basename(file)
+            with open(file, 'r') as f:
+                contents = f.read()
+                map_contents = file_contents_map.get(basename.replace('netplan-sriov-', ''))
+                self.assertEqual(map_contents, contents)
