@@ -21,24 +21,23 @@ import ctypes
 import os
 import shutil
 import tempfile
+import unittest
 import io
 import yaml
 
 from generator.base import TestBase
 from parser.base import capture_stderr
-from tests.test_utils import MockCmd
 
 from utils import state_from_yaml
 from netplan_cli.cli.commands.set import FALLBACK_FILENAME
+from netplan_cli.cli.ovs import OPENVSWITCH_OVS_VSCTL
 
 import netplan
 from netplan.netdef import NetplanRoute
 
 # We still need direct (ctypes) access to libnetplan.so to test certain cases
 # that are not covered by the 'netplan' module bindings
-lib = ctypes.CDLL(ctypes.util.find_library('netplan'))
-# Define some libnetplan.so ABI
-lib.netplan_get_id_from_nm_filename.restype = ctypes.c_char_p
+lib = ctypes.CDLL('libnetplan.so.1')
 
 rootdir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 exe_cli = os.path.join(rootdir, 'src', 'netplan.script')
@@ -53,48 +52,15 @@ class TestRawLibnetplan(TestBase):
 
     def tearDown(self):
         shutil.rmtree(self.workdir.name)
-        lib.netplan_clear_netdefs()
         super().tearDown()
 
-    def test_get_id_from_filename(self):
-        out = lib.netplan_get_id_from_nm_filename(
-          '/run/NetworkManager/system-connections/netplan-some-id.nmconnection'.encode(), None)
-        self.assertEqual(out, b'some-id')
-
-    def test_get_id_from_filename_rootdir(self):
-        out = lib.netplan_get_id_from_nm_filename(
-          '/some/rootdir/run/NetworkManager/system-connections/netplan-some-id.nmconnection'.encode(), None)
-        self.assertEqual(out, b'some-id')
-
-    def test_get_id_from_filename_wifi(self):
-        out = lib.netplan_get_id_from_nm_filename(
-          '/run/NetworkManager/system-connections/netplan-some-id-SOME-SSID.nmconnection'.encode(), 'SOME-SSID'.encode())
-        self.assertEqual(out, b'some-id')
-
-    def test_get_id_from_filename_wifi_invalid_suffix(self):
-        out = lib.netplan_get_id_from_nm_filename(
-          '/run/NetworkManager/system-connections/netplan-some-id-SOME-SSID'.encode(), 'SOME-SSID'.encode())
-        self.assertEqual(out, None)
-
-    def test_get_id_from_filename_invalid_prefix(self):
-        out = lib.netplan_get_id_from_nm_filename('INVALID/netplan-some-id.nmconnection'.encode(), None)
-        self.assertEqual(out, None)
-
     def test_parse_keyfile_missing(self):
+        parser = netplan.Parser()
         f = os.path.join(self.workdir.name, 'tmp/some.keyfile')
         os.makedirs(os.path.dirname(f))
-        with capture_stderr() as outf:
-            self.assertFalse(lib.netplan_parse_keyfile(f.encode(), None))
-            with open(outf.name, 'r') as f:
-                self.assertIn('netplan: cannot load keyfile', f.read().strip())
-
-    def test_generate(self):
-        self.mock_netplan_cmd = MockCmd("netplan")
-        os.environ["TEST_NETPLAN_CMD"] = self.mock_netplan_cmd.path
-        self.assertTrue(lib.netplan_generate(self.workdir.name.encode()))
-        self.assertEqual(self.mock_netplan_cmd.calls(), [
-            ["netplan", "generate", "--root-dir", self.workdir.name],
-        ])
+        with self.assertRaises(netplan.NetplanException) as ctx:
+            parser.load_keyfile(f)
+        self.assertIn('No such file or directory', str(ctx.exception))
 
     def test_delete_connection(self):
         os.environ["TEST_NETPLAN_CMD"] = exe_cli
@@ -151,28 +117,6 @@ class TestRawLibnetplan(TestBase):
             with open(outf.name, 'r') as f:
                 self.assertIn('Cannot parse input', f.read())
 
-    def test_write_netplan_conf(self):
-        netdef_id = 'some-netplan-id'
-        orig = os.path.join(self.confdir, 'some-filename.yaml')
-        generated = os.path.join(self.confdir, '10-netplan-{}.yaml'.format(netdef_id))
-        with open(orig, 'w') as f:
-            f.write('''network:
-  version: 2
-  ethernets:
-    some-netplan-id:
-      renderer: networkd
-      match:
-        name: "eth42"
-''')
-        # Parse YAML and and re-write the specified netdef ID into a new file
-        self.assertTrue(lib.netplan_parse_yaml(orig.encode(), None))
-        lib._write_netplan_conf(netdef_id.encode(), self.workdir.name.encode())
-        self.assertEqual(lib.netplan_clear_netdefs(), 1)
-        self.assertTrue(os.path.isfile(generated))
-        with open(orig, 'r') as f:
-            with open(generated, 'r') as new:
-                self.assertEqual(f.read(), new.read())
-
 
 class TestNetdefIterator(TestBase):
     def test_with_empty_netplan(self):
@@ -615,6 +559,8 @@ class TestNetDefinition(TestBase):
         netdef = state['eth0']
         self.assertEqual(os.path.join(self.confdir, "a.yaml"), netdef.filepath)
 
+    @unittest.skipIf(not os.path.exists(OPENVSWITCH_OVS_VSCTL),
+                     'OpenVSwitch not installed')
     def test_filepath_for_ovs_ports(self):
         state = state_from_yaml(self.confdir, '''network:
   version: 2
@@ -634,6 +580,8 @@ class TestNetDefinition(TestBase):
         self.assertEqual(os.path.join(self.confdir, "a.yaml"), netdef_port1.filepath)
         self.assertEqual(os.path.join(self.confdir, "a.yaml"), netdef_port2.filepath)
 
+    @unittest.skipIf(not os.path.exists(OPENVSWITCH_OVS_VSCTL),
+                     'OpenVSwitch not installed')
     def test_filepath_for_ovs_ports_when_conf_is_redefined(self):
         state = netplan.State()
         parser = netplan.Parser()
@@ -793,6 +741,31 @@ class TestNetDefinition(TestBase):
 
         self.assertIsNone(state['eth0'].links.get('bond'))
 
+    def test_interface_has_pointer_to_vrf(self):
+        state = state_from_yaml(self.confdir, '''network:
+  ethernets:
+    eth0:
+      dhcp4: false
+  vrfs:
+    vrf0:
+      table: 1000
+      interfaces:
+        - eth0
+      ''')
+
+        self.assertEqual(state['eth0'].links.get('vrf').id, "vrf0")
+
+    def test_interface_pointer_to_vrf_is_none(self):
+        state = state_from_yaml(self.confdir, '''network:
+  ethernets:
+    eth0:
+      dhcp4: false
+      ''')
+
+        self.assertIsNone(state['eth0'].links.get('vrf'))
+
+    @unittest.skipIf(not os.path.exists(OPENVSWITCH_OVS_VSCTL),
+                     'OpenVSwitch not installed')
     def test_interface_has_pointer_to_peer(self):
         state = state_from_yaml(self.confdir, '''network:
   openvswitch:
@@ -831,6 +804,43 @@ class TestNetDefinition(TestBase):
         self.assertFalse(state['eth0'].dhcp4)
         self.assertTrue(state['eth0'].dhcp6)
 
+    def test_link_local(self):
+        state = state_from_yaml(self.confdir, '''network:
+  ethernets:
+    eth0:
+      link-local: [ipv4, ipv6]
+      ''')
+
+        self.assertIn('ipv4', state['eth0'].link_local)
+        self.assertIn('ipv6', state['eth0'].link_local)
+
+        state = state_from_yaml(self.confdir, '''network:
+  ethernets:
+    eth0:
+      link-local: []
+      ''')
+
+        self.assertNotIn('ipv4', state['eth0'].link_local)
+        self.assertNotIn('ipv6', state['eth0'].link_local)
+
+        state = state_from_yaml(self.confdir, '''network:
+  ethernets:
+    eth0:
+      link-local: [ipv4]
+      ''')
+
+        self.assertIn('ipv4', state['eth0'].link_local)
+        self.assertNotIn('ipv6', state['eth0'].link_local)
+
+        state = state_from_yaml(self.confdir, '''network:
+  ethernets:
+    eth0:
+      link-local: [ipv6]
+      ''')
+
+        self.assertNotIn('ipv4', state['eth0'].link_local)
+        self.assertIn('ipv6', state['eth0'].link_local)
+
     def test_get_macaddress(self):
         state = state_from_yaml(self.confdir, '''network:
   ethernets:
@@ -984,3 +994,33 @@ tail:
         '''
         with self.assertRaises(ValueError):
             netplan.NetplanParserException('not the expected file path, line and column', 0, 0)
+
+    def test_netdef_get_bond_mode(self):
+        state = state_from_yaml(self.confdir, '''network:
+  ethernets:
+    eth0:
+      dhcp4: false
+  bonds:
+    bond0:
+      parameters:
+        mode: active-backup
+      dhcp4: false
+      interfaces:
+        - eth0
+      ''')
+
+        self.assertEqual(state['bond0']._bond_mode, "active-backup")
+
+    def test_netdef_get_bond_mode_unset(self):
+        state = state_from_yaml(self.confdir, '''network:
+  ethernets:
+    eth0:
+      dhcp4: false
+  bonds:
+    bond0:
+      dhcp4: false
+      interfaces:
+        - eth0
+      ''')
+
+        self.assertIsNone(state['bond0']._bond_mode)
