@@ -354,6 +354,26 @@ class TestUtils(unittest.TestCase):
             ['systemctl', 'is-enabled', 'some.service']
         ])
 
+    def test_systemctl_is_installed(self):
+        self.mock_cmd = MockCmd('systemctl')
+        self.mock_cmd.set_returncode(0)
+        path_env = os.environ['PATH']
+        os.environ['PATH'] = os.path.dirname(self.mock_cmd.path) + os.pathsep + path_env
+        self.assertTrue(utils.systemctl_is_installed('some.service'))
+        self.assertEqual(self.mock_cmd.calls(), [
+            ['systemctl', 'is-enabled', 'some.service']
+        ])
+
+    def test_systemctl_is_installed_false(self):
+        self.mock_cmd = MockCmd('systemctl')
+        self.mock_cmd.set_returncode(4)
+        path_env = os.environ['PATH']
+        os.environ['PATH'] = os.path.dirname(self.mock_cmd.path) + os.pathsep + path_env
+        self.assertFalse(utils.systemctl_is_installed('some.service'))
+        self.assertEqual(self.mock_cmd.calls(), [
+            ['systemctl', 'is-enabled', 'some.service']
+        ])
+
     def test_systemctl_daemon_reload(self):
         self.mock_cmd = MockCmd('systemctl')
         path_env = os.environ['PATH']
@@ -383,3 +403,22 @@ class TestUtils(unittest.TestCase):
         nmcli.return_value = 'CONNECTION \n--         \n'
         out = utils.nm_get_connection_for_interface('asd0')
         self.assertEqual(out, '')
+
+    @patch('builtins.open')
+    def test_route_table_lookup(self, open_mock):
+        file = io.StringIO()
+        data = '#\n# reserved values\n#\n255\tlocal\n254\tmain\n253\tdefault\n0\tunspec\n#\n# local\n#\n#1\tinr.ruhep\n'
+        file.write(data)
+        file.seek(0)
+        open_mock.return_value = file
+        expected = {0: 'unspec', 253: 'default', 254: 'main', 255: 'local',
+                    'unspec': 0, 'default': 253, 'main': 254, 'local': 255}
+        out = utils.route_table_lookup()
+        self.assertDictEqual(out, expected)
+
+    @patch('builtins.open')
+    def test_route_table_lookup_fail(self, open_mock):
+        open_mock.side_effect = Exception
+        out = utils.route_table_lookup()
+        self.assertDictEqual(out, {0: 'unspec', 253: 'default', 254: 'main', 255: 'local',
+                                   'unspec': 0, 'default': 253, 'main': 254, 'local': 255})
